@@ -338,7 +338,7 @@ class Playlist(GObject.GObject):
 
         return self._model
 
-    @model.setter
+    @model.setter  # type: ignore
     def model(self, value):
         self._model = value
 
@@ -445,7 +445,7 @@ class Playlist(GObject.GObject):
         """
         return self._title
 
-    @title.setter
+    @title.setter  # type: ignore
     def title(self, new_name):
         """Rename a playlist
 
@@ -639,7 +639,6 @@ class Playlist(GObject.GObject):
     def add_songs(self, coresongs):
         """Adds songs to the playlist
 
-        :param Playlist playlist:
         :param list coresongs: list of Coresong
         """
         def _add_to_model(source, op_id, media, remaining, error):
